==> homesitemaker-v0.4.2.tar.gz: homesitemaker/includes/control-panel/users/cp_help.php <==
<?php

/*
Home Site Maker, the websites factory.
Copyright (C) 2004, 2005 Marcos Martinez Jimenez

This file is part of Home Site Maker.

    Home Site Maker is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Home Site Maker is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Home Site Maker; see the file COPYING. If not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA


Marcos Martinez Jimenez
marcos@assl-site.net
http://homesitemaker.no-ip.org
Francesc Llunell n 1 4 5, Esplugues de Llobregat, 08950 Barcelona, Spain
*/


include ("includes/languages/".$LANGUAGE."/homesite-includes-control-panel-users-cp_help.php");

echo "$TEXT001:<br>&nbsp;</td></tr>".
     "<tr><td class=\"text2\" valign=\"top\"><b>$TAB_51</b>:</td>".
     "<td class=\"text2\"> $TEXT002.<br>&nbsp;</td></tr>".
     "<tr><td class=\"text2\" valign=\"top\"><b>$TAB_52</b>:</td>".
     "<td class=\"text2\"> $TEXT003<br>&nbsp;</td></tr>".
     "<tr><td class=\"text2\" valign=\"top\"><b>$TAB_53</b>:</td>".
     "<td class=\"text2\"> $TEXT004.<br>&nbsp;</td></tr>".
     "<tr><td class=\"text2\" valign=\"top\"><b>$TAB_54</b>:</td>".
     "<td class=\"text2\"> $TEXT005.&nbsp;</td></tr>".
     "<tr><td class=\"text6\" colspan=\"2\">&nbsp;</td></tr>";
?>

==> homesitemaker-v0.4.7-1.tar.gz: homesitemaker/includes/control-panel/users/cp_help.php <==
<?php

/*
Home Site Maker, the websites factory.
Copyright (C) 2004, 2005 Marcos Martinez Jimenez

This file is part of Home Site Maker.

    Home Site Maker is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Home Site Maker is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Home Site Maker; see the file COPYING. If not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA


Marcos Martinez Jimenez
marcos@assl-site.net
http://homesitemaker.no-ip.org
Francesc Llunell n 1 4 5, Esplugues de Llobregat, 08950 Barcelona, Spain
*/


include ("includes/languages/".$LANGUAGE."/homesite-includes-control-panel-users-cp_help.php");

echo "<tr><td class=\"title1\" colspan=\"2\">".
     "<img src=\"images/skins/$ICONS/icons/png/$ICON_SIZE2/Help.png\">&nbsp;Help</td></tr>".
     "<tr><td colspan=2 class=\"text2\"><br>$TEXT001:<br>&nbsp;</td></tr>".
     "<tr><td class=\"text2\" valign=\"top\"><b>$TAB_51</b>:</td>".
     "<td class=\"text2\"> $TEXT002.<br>&nbsp;</td></tr>".
     "<tr><td class=\"text2\" valign=\"top\"><b>$TAB_52</b>:</td>".
     "<td class=\"text2\"> $TEXT003<br>&nbsp;</td></tr>".
     "<tr><td class=\"text2\" valign=\"top\"><b>$TAB_53</b>:</td>".
     "<td class=\"text2\"> $TEXT004.<br>&nbsp;</td></tr>".
     "<tr><td class=\"text2\" valign=\"top\"><b>$TAB_54</b>:</td>".
     "<td class=\"text2\"> $TEXT005.&nbsp;</td></tr>".
     "<tr><td class=\"text6\" colspan=\"2\">&nbsp;</td></tr>";
?>
